@@ -20,10 +20,10 @@ has 'dbhandle' => (
     isa => 'DBI::db',
 );
 
-my $connection_string   = Zonemaster::Backend::Config->DB_connection_string( 'postgresql' );
+my $connection_string   = Zonemaster::Backend::Config->load_config()->DB_connection_string( 'postgresql' );
 my $connection_args     = { RaiseError => 1, AutoCommit => 1 };
-my $connection_user     = Zonemaster::Backend::Config->DB_user();
-my $connection_password = Zonemaster::Backend::Config->DB_password();
+my $connection_user     = Zonemaster::Backend::Config->load_config()->DB_user();
+my $connection_password = Zonemaster::Backend::Config->load_config()->DB_password();
 
 sub dbh {
     my ( $self ) = @_;
@@ -34,6 +34,8 @@ sub dbh {
     }
     else {
         $dbh = DBI->connect( $connection_string, $connection_user, $connection_password, $connection_args );
+#        $dbh->{InactiveDestroy} = 1;
+# This line vas introduced to fix a non-trivial, hard to reproduce problem, it is causing giant memory leaks. It is kept here commented out for a while in case the initial problem occurs again.
         $dbh->{AutoInactiveDestroy} = 1;
         $self->dbhandle( $dbh );
         return $dbh;
@@ -118,18 +120,15 @@ sub create_new_test {
     my $result;
     my $dbh = $self->dbh;
 
-    my $priority = 10;
-    $priority = $test_params->{priority} if (defined $test_params->{priority});
-    
-    my $queue = 0;
-    $queue = $test_params->{queue} if (defined $test_params->{queue});
-    
     $test_params->{domain} = $domain;
     my $js = JSON::PP->new;
     $js->canonical( 1 );
     my $encoded_params                 = $js->encode( $test_params );
     my $test_params_deterministic_hash = md5_hex( encode_utf8( $encoded_params ) );
 
+    my $priority = $test_params->{priority};
+    my $queue = $test_params->{queue};
+
     my $query =
         "INSERT INTO test_results (batch_id, priority, queue, params_deterministic_hash, params) SELECT "
       . $dbh->quote( $batch_id ) . ", "
@@ -144,7 +143,7 @@ sub create_new_test {
     my ( $id, $hash_id ) = $dbh->selectrow_array(
         "SELECT id, hash_id FROM test_results WHERE params_deterministic_hash='$test_params_deterministic_hash' ORDER BY id DESC LIMIT 1" );
         
-    if ( $id > Zonemaster::Backend::Config->force_hash_id_use_in_API_starting_from_id() ) {
+    if ( $id > Zonemaster::Backend::Config->load_config()->force_hash_id_use_in_API_starting_from_id() ) {
         $result = $hash_id;
     }
     else {
@@ -194,13 +193,9 @@ sub get_test_history {
 
     my $dbh = $self->dbh;
 
-    my $use_hash_id_from_id = Zonemaster::Backend::Config->force_hash_id_use_in_API_starting_from_id();
+    my $use_hash_id_from_id = Zonemaster::Backend::Config->load_config()->force_hash_id_use_in_API_starting_from_id();
     my $undelegated = "";
-    if ($p->{filter} eq "old_behavior" ) {
-        $undelegated = (defined $p->{frontend_params}->{nameservers})
-            ? ("AND (params->'nameservers') IS NOT NULL")
-            : ("AND (params->'nameservers') IS NULL");
-    } elsif ($p->{filter} eq "undelegated") {
+    if ($p->{filter} eq "undelegated") {
         $undelegated = "AND (params->'nameservers') IS NOT NULL";
     } elsif ($p->{filter} eq "delegated") {
         $undelegated = "AND (params->'nameservers') IS NULL";
@@ -214,9 +209,8 @@ sub get_test_history {
             (SELECT count(*) FROM (SELECT json_array_elements(results) AS result) AS t1 WHERE result->>'level'='WARNING') AS nb_warning,
             id,
             hash_id,
-            creation_time at time zone current_setting('TIMEZONE') at time zone 'UTC' as creation_time, 
-            params->>'advanced_options' AS advanced_options 
-        FROM test_results 
+            creation_time at time zone current_setting('TIMEZONE') at time zone 'UTC' as creation_time
+        FROM test_results
         WHERE params->>'domain'=" . $dbh->quote( $p->{frontend_params}->{domain} ) . " $undelegated 
         ORDER BY id DESC 
         OFFSET $p->{offset} LIMIT $p->{limit}";
@@ -239,8 +233,7 @@ sub get_test_history {
             {
                 id               => ($h->{id} > $use_hash_id_from_id)?($h->{hash_id}):($h->{id}),
                 creation_time    => $h->{creation_time},
-                advanced_options => $h->{advanced_options},
-                overall_result   => $overall_result
+                overall_result   => $overall_result,
             }
         );
     }
@@ -255,23 +248,15 @@ sub add_batch_job {
     my $dbh = $self->dbh;
     my $js = JSON::PP->new;
     $js->canonical( 1 );
-            
-    if ( $self->user_authorized( $params->{username}, $params->{api_key} ) ) {
-        $params->{test_params}->{client_id}      = 'Zonemaster Batch Scheduler';
-        $params->{test_params}->{client_version} = '1.0';
-        $params->{test_params}->{priority} = 5 unless (defined $params->{test_params}->{priority});
 
+    if ( $self->user_authorized( $params->{username}, $params->{api_key} ) ) {
         $batch_id = $self->create_new_batch_job( $params->{username} );
 
-        my $minutes_between_tests_with_same_params = 5;
         my $test_params = $params->{test_params};
-        
-        my $priority = 10;
-        $priority = $test_params->{priority} if (defined $test_params->{priority});
-        
-        my $queue = 0;
-        $queue = $test_params->{queue} if (defined $test_params->{queue});
-        
+
+        my $priority = $test_params->{priority};
+        my $queue = $test_params->{queue};
+
         $dbh->begin_work();
         $dbh->do( "ALTER TABLE test_results DROP CONSTRAINT IF EXISTS test_results_pkey" );
         $dbh->do( "DROP INDEX IF EXISTS test_results__hash_id" );
