@@ -8,26 +8,44 @@ use 5.14.2;
 use DBI qw(:utils);
 use JSON::PP;
 use Scalar::Util qw( blessed );
+use File::Slurp;
 
 use Zonemaster::LDNS;
 
 use Zonemaster::Engine;
 use Zonemaster::Engine::Translator;
 use Zonemaster::Backend::Config;
+use Zonemaster::Engine::Profile;
 
 sub new {
     my ( $class, $params ) = @_;
     my $self = {};
 
+    if ( $params && $params->{config} ) {
+        $self->{config} = $params->{config};
+    }
+
     if ( $params && $params->{db} ) {
         eval "require $params->{db}";
         $self->{db} = "$params->{db}"->new();
     }
     else {
-        my $backend_module = "Zonemaster::Backend::DB::" . Zonemaster::Backend::Config->BackendDBType();
+        my $backend_module = "Zonemaster::Backend::DB::" . $self->{config}->BackendDBType();
         eval "require $backend_module";
         $self->{db} = $backend_module->new();
     }
+        
+    $self->{profiles} = $self->{config}->ReadProfilesInfo();
+    foreach my $profile (keys %{$self->{profiles}}) {
+        die "default profile cannot be private" if ($profile eq 'default' && $self->{profiles}->{$profile}->{type} eq 'private');
+        if ( -e $self->{profiles}->{$profile}->{profile_file_name} ) {
+            my $json = read_file( $self->{profiles}->{$profile}->{profile_file_name}, err_mode => 'croak' );
+            $self->{profiles}->{$profile}->{zm_profile} = Zonemaster::Engine::Profile->from_json( $json );
+        }
+        elsif ($profile ne 'default') {
+            die "the profile definition json file of the profile [$profile] defined in the backend config file can't be read";
+        }
+    }
 
     bless( $self, $class );
     return $self;
@@ -59,13 +77,12 @@ sub run {
     }
     $domain = $self->to_idn( $domain );
 
-    if (defined $params->{ipv4} || defined $params->{ipv6}) {
-        Zonemaster::Engine->config->get->{net}{ipv4} = ( $params->{ipv4} ) ? ( 1 ) : ( 0 );
-        Zonemaster::Engine->config->get->{net}{ipv6} = ( $params->{ipv6} ) ? ( 1 ) : ( 0 );
+    if (defined $params->{ipv4}) {
+        Zonemaster::Engine::Profile->effective->set( q{net.ipv4}, ( $params->{ipv4} ) ? ( 1 ) : ( 0 ) );
     }
-    else {
-        Zonemaster::Engine->config->get->{net}{ipv4} = 1;
-        Zonemaster::Engine->config->get->{net}{ipv6} = 1;
+
+    if (defined $params->{ipv6}) {
+        Zonemaster::Engine::Profile->effective->set( q{net.ipv6}, ( $params->{ipv6} ) ? ( 1 ) : ( 0 ) );
     }
 
     # used for progress indicator
@@ -124,29 +141,14 @@ sub run {
 
     # If the profile parameter has been set in the API, then load a profile
     if ( $params->{profile} ) {
-        if ( $params->{profile} eq 'test_profile_1' and Zonemaster::Backend::Config->CustomProfilesPath()) {
-            # The config has defined an alternative profile and "test_profile_1" has been set.
-            Zonemaster::Engine->config->load_policy_file( Zonemaster::Backend::Config->CustomProfilesPath() . '/policy.json' );
-        }
-        else { # The profile parameter has been set to something else or alternative profile is not defined
-            Zonemaster::Engine->config->load_policy_file( 'policy.json' );
-        }
-    # It will be silently ignored if the file does not exist.
-    }
-
-
-    if ( $params->{config} ) {
-        my $config_file_path = Zonemaster::Backend::Config->GetCustomConfigParameter('ZONEMASTER', $params->{config});
-        if ($config_file_path) {
-            if (-e $config_file_path) {
-                Zonemaster::Engine->config->load_config_file( $config_file_path );
-            }
-            else {
-                die "The file specified by the config parameter value: [$params->{config}] doesn't exist";
-            }
+        $params->{profile} = lc($params->{profile});
+        if (defined $self->{profiles}->{$params->{profile}} && $self->{profiles}->{$params->{profile}}->{zm_profile}) { 
+            my $profile = Zonemaster::Engine::Profile->default;
+            $profile->merge( $self->{profiles}->{$params->{profile}}->{zm_profile} );
+            Zonemaster::Engine::Profile->effective->merge( $profile );
         }
         else {
-            die "Unknown test configuration: [$params->{config}]\n"
+            die "The profile [$params->{profile}] is not defined in the backend_config ini file" if ($params->{profile} ne 'default')
         }
     }
 
@@ -169,6 +171,11 @@ sub run {
     return;
 } ## end sub run
 
+sub reset {
+    my ( $self ) = @_;
+    Zonemaster::Engine->reset();
+}
+
 sub add_fake_delegation {
     my ( $self, $domain, $nameservers ) = @_;
     my @ns_with_no_ip;
